#
# Copyright Michael Orlitzky
#
# http://michael.orlitzky.com/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# http://www.fsf.org/licensing/licenses/gpl.html
#

require 'test/unit'
require 'src/websites/redtube'

# Unit tests for the Redtube class. Basically just checking
# the results of get_video_url for known ids.

class RedtubeTest < Test::Unit::TestCase

  def test_owns_redtube_urls
    assert(Redtube.owns_url?('http://www.redtube.com/6807'))
    assert(Redtube.owns_url?('www.redtube.com/6807'))
    assert(Redtube.owns_url?('http://redtube.com/6807'))
    assert(Redtube.owns_url?('redtube.com/6807'))
  end

  
  def test_doesnt_own_howcast_urls
    assert(!Redtube.owns_url?('http://www.howcast.com/6807'))
    assert(!Redtube.owns_url?('www.howcast.com/6807'))
    assert(!Redtube.owns_url?('http://howcast.com/6807'))
    assert(!Redtube.owns_url?('howcast.com/6807'))
  end

  
  def test_doesnt_own_misc_urls
    assert(!Redtube.owns_url?('http://redtube/123'))
    assert(!Redtube.owns_url?('www.redtube.com/abc'))
  end


  def test_parse_hashlink
    rt = Redtube.new(nil)

    page_data = nil

    File.open('test/fixtures/redtube/6807.html') do |f|
      page_data = f.read
    end

    test_result = rt.send('parse_hashlink', page_data)
    assert_equal('http://cdn.llnw.redtube.com/s/0000006/X57OBH08G.flv?rs=180&ri=2048&e=1270165515&h=22ef939c416ddb6e8f8e3071f7b9503d', test_result)
  end
  
end
